@@ -33,12 +33,12 @@
 (defmacro no-warning (form)
   #+sbcl `(handler-bind
 	     ((style-warning #'muffle-warning)
-	      #+sbcl (sb-ext:compiler-note #'muffle-warning))
+              (sb-ext:compiler-note #'muffle-warning))
 	   ,form)
   #+clisp `(let ((custom:*suppress-check-redefinition* t)) ,form)
   #-(or sbcl clisp) `(progn ,form))
 
-($put '$wxmaxima `((mlist simp) 0 8 4) '$version)
+($put '$wxmaxima `((mlist simp) 0 8 7) '$version)
 
 (setf (get '$inchar 'assign) 'neverset)
 (setf (get '$outchar 'assign) 'neverset)
@@ -96,10 +96,9 @@
 (defun wxxml-atom (x l r &aux tmp-x)
   (append l
           (list (cond ((numberp x) (wxxmlnumformat x))
-                      ((typep x 'structure-object)
-		       (format nil "<v>Structure [~A]</v>" (type-of x)))
-		      ((hash-table-p x)
-		       (format nil "<v>HashTable</v>"))
+                      ((and (symbolp x) (get x 'wxxmlword)))
+                      ((and (symbolp x) (get x 'reversealias))
+                       (wxxml-stripdollar (get x 'reversealias)))
 		      ((stringp x)
 		       (setq tmp-x (wxxml-fix-string x))
 		       (if (and (boundp '$stringdisp) $stringdisp)
@@ -108,14 +107,16 @@
 		      ((arrayp x)
 		       (format nil "<v>Lisp array [~{~a~^,~}]</v>"
 			       (array-dimensions x)))
-                      ((and (symbolp x) (get x 'wxxmlword)))
-                      ((and (symbolp x) (get x 'reversealias))
-                       (wxxml-stripdollar (get x 'reversealias)))
 		      ((streamp x)
 		       (format nil "<v>Stream [~A]</v>"
 			       (stream-element-type x)))
-                      (t (wxxml-stripdollar x))
-		      ))
+		      ((member (type-of x) '(GRAPH DIGRAPH))
+		       (format nil "<v>~a</v>" x))
+                      ((typep x 'structure-object)
+		       (format nil "<v>Structure [~A]</v>" (type-of x)))
+		      ((hash-table-p x)
+		       (format nil "<v>HashTable</v>"))
+                      (t (wxxml-stripdollar x))))
 	  r))
 
 (defun wxxmlnumformat (atom)
@@ -788,7 +789,7 @@
 (defprop mleqp 80. wxxml-rbp)
 
 (defprop mnot wxxml-prefix wxxml)
-(defprop mnot ("<fnm>not</fnm>") wxxmlsym)
+(defprop mnot ("<fnm altCopy=\"not \">not</fnm>") wxxmlsym)
 (defprop mnot "<fnm>not</fnm>" wxxmlword)
 (defprop mnot 70. wxxml-rbp)
 
@@ -814,13 +815,22 @@
 (defprop %derivative 119. wxxml-rbp)
 
 (defun wxxml-derivative (x l r)
-  (if $derivabbrev
-      (append l
-	      (wxxml-d-abbrev x)
-	      r)
+  (if (and $derivabbrev (every #'integerp (odds (cddr x) 0)))
+      (append l (wxxml-d-abbrev x) r)
       (wxxml (wxxml-d x) (append l '("<d>"))
 	     (append '("</d>") r) 'mparen 'mparen)))
 
+(defun $derivabbrev (a)
+  (if a
+      (progn
+	(defprop %derivative 130. wxxml-lbp)
+	(defprop %derivative 129. wxxml-rbp)
+	(setq $derivabbrev t))
+      (progn
+	(defprop %derivative 120. wxxml-lbp)
+	(defprop %derivative 119. wxxml-rbp)
+	(setq $derivabbrev nil))))
+
 (defun wxxml-d-abbrev-subscript (l_vars l_ords &aux var_xml)
   (let ((sub ()))
     (loop while l_vars do
@@ -961,7 +971,7 @@
                      (list
 		      (format nil "<lbl>(~A)~A </lbl>"
 			      (stripdollar (maybe-invert-string-case (symbol-name (cadr x))))
-				  *wxxml-mratp*))
+                              *wxxml-mratp*))
 		     nil))
          r 'mparen 'mparen))
 
@@ -974,9 +984,9 @@
 
 (defun mydispla (x)
   (let ((*print-circle* nil)
-	    (*wxxml-mratp* (format nil "~{~a~}" (cdr (checkrat x)))))
-	(mapc #'princ
-		(wxxml x '("<mth>") '("</mth>") 'mparen 'mparen))))
+        (*wxxml-mratp* (format nil "~{~a~}" (cdr (checkrat x)))))
+    (mapc #'princ
+          (wxxml x '("<mth>") '("</mth>") 'mparen 'mparen))))
 
 (setf *alt-display2d* 'mydispla)
 
@@ -995,6 +1005,10 @@
      (setq tp '$unknown)))
   tp)
 
+;;
+;; inference_result from the stats package
+;;
+
 (defun wxxml-inference (x l r)
   (let ((name (cadr x))
 	(values (caddr x))
@@ -1011,6 +1025,96 @@
 
 (defprop $inference_result wxxml-inference wxxml)
 
+(defun wxxml-amatrix (x l r)
+  (let* ((nr ($@-function x '$nr))
+	 (nc ($@-function x '$nc))
+	 (M (simplifya ($genmatrix
+			`((lambda) ((mlist) i j) (mfuncall '$get_element ,x i j))
+			nr nc)
+		       t)))
+    (wxxml-matrix M l r)))
+
+(defprop $amatrix wxxml-amatrix wxxml)
+
+;;
+;; orthopoly functions
+;;
+
+(defun wxxml-pochhammer (x l r)
+  (let ((n (cadr x))
+	(k (caddr x)))
+    (append l
+	    (list (format nil "<i altCopy=\"~{~a~}\"><p>" (mstring x)))
+	    (wxxml n nil nil 'mparen 'mparen)
+	    (list "</p><r>")
+	    (wxxml k nil nil 'mparen 'mparen)
+	    (list "</r></i>")
+	    r)))
+
+(defprop $pochhammer wxxml-pochhammer wxxml)
+
+(defun wxxml-orthopoly (x l r)
+  (let* ((fun-name (caar x))
+	 (disp-name (get fun-name 'wxxml-orthopoly-disp))
+	 (args (cdr x)))
+    (append l
+	    (list (format nil "<fn altCopy=\"~{~a~}\">" (mstring x)))
+	    (if (nth 2 disp-name)
+		(list (format nil "<ie><fnm>~a</fnm><r>" (car disp-name)))
+		(list (format nil "<i><fnm>~a</fnm><r>" (car disp-name))))
+	    (wxxml (nth (nth 1 disp-name) args) nil nil 'mparen 'mparen)
+	    (when (nth 2 disp-name)
+	      (append (list "</r><r>")
+		      (when (nth 3 disp-name) (list "<p>"))
+		      (wxxml-list (or (nth 5 disp-name)
+				      (mapcar (lambda (i) (nth i args)) (nth 2 disp-name)))
+				  nil nil ",")
+		      (when (nth 3 disp-name) (list "</p>"))
+		      (list "</r>")))
+	    (if (nth 2 disp-name)
+		(list "</ie>")
+		(list "</r></i>"))
+	    (list "<p>")
+	    (wxxml-list (mapcar (lambda (i) (nth i args)) (nth 4 disp-name)) nil nil ",")
+	    (list "</p></fn>")
+	    r)))
+
+(dolist (ortho-pair
+	  '(($laguerre "L" 0 nil nil (1))
+	    (%laguerre "L" 0 nil nil (1))
+	    ($legendre_p "P" 0 nil nil (1))
+	    (%legendre_p "P" 0 nil nil (1))
+	    ($legendre_q "Q" 0 nil nil (1))
+	    (%legendre_q "Q" 0 nil nil (1))
+	    ($chebyshev_t "T" 0 nil nil (1))
+	    (%chebyshev_t "T" 0 nil nil (1))
+	    ($chebyshev_u "U" 0 nil nil (1))
+	    (%chebyshev_u "U" 0 nil nil (1))
+	    ($hermite "H" 0 nil nil (1))
+	    (%hermite "H" 0 nil nil (1))
+	    ($spherical_bessel_j "J" 0 nil nil (1))
+	    (%spherical_bessel_j "J" 0 nil nil (1))
+	    ($spherical_bessel_y "Y" 0 nil nil (1))
+	    (%spherical_bessel_y "Y" 0 nil nil (1))
+	    ($assoc_legendre_p "P" 0 (1) nil (2))
+	    (%assoc_legendre_p "P" 0 (1) nil (2))
+	    ($assoc_legendre_q "Q" 0 (1) nil (2))
+	    (%assoc_legendre_q "Q" 0 (1) nil (2))
+	    ($jacobi_p "P" 0 (1 2) t (3))
+	    (%jacobi_p "P" 0 (1 2) t (3))
+	    ($gen_laguerre "L" 0 (1) t (2))
+	    (%gen_laguerre "L" 0 (1) t (2))
+	    ($spherical_harmonic "Y" 0 (1) nil (2 3))
+	    (%spherical_harmonic "Y" 0 (1) nil (2 3))
+	    ($ultraspherical "C" 0 (1) t (2))
+	    (%ultraspherical "C" 0 (1) t (2))
+	    ($spherical_hankel1 "H" 0 t t (1) (1))
+	    (%spherical_hankel1 "H" 0 t t (1) (1))
+	    ($spherical_hankel2 "H" 0 t t (1) (2))
+	    (%spherical_hankel2 "H" 0 t t (1) (2))))
+  (setf (get (car ortho-pair) 'wxxml) 'wxxml-orthopoly)
+  (setf (get (car ortho-pair) 'wxxml-orthopoly-disp) (cdr ortho-pair)))
+
 ;;;
 ;;; This is the display support only - copy/paste will not work
 ;;;
@@ -1091,7 +1195,7 @@
 	    ($first $wxplot_size)
 	    ($second $wxplot_size))))
 
-(defun $int_range (lo &optional hi)
+(defun $int_range (lo &optional hi (st 1))
   (unless (integerp lo)
     ($error "int_range: first argument is not an integer."))
   (unless (or (null hi) (integerp hi))
@@ -1099,7 +1203,7 @@
   (when (null hi)
     (setq hi lo)
     (setq lo 1))
-  (cons '(mlist simp) (loop for i from lo to hi collect i)))
+  (cons '(mlist simp) (loop :for i :from lo :to hi :by st :collect i)))
 
 (defun wxanimate (scene)
   (let* ((scene (cdr scene))
@@ -1109,7 +1213,7 @@
 	 (args (cdddr scene))
 	 (images ()))
     (when (integerp a-range)
-      (setq a-range (mfuncall '$makelist 'i 'i 1 a-range)))
+      (setq a-range (cons '(mlist simp) (loop for i from 1 to a-range collect i))))
     (dolist (aval (reverse (cdr a-range)))
       (let ((preamble ($wxplot_preamble))
 	    (system-preamble (get-plot-option-string '$gnuplot_preamble 2))
@@ -1121,14 +1225,15 @@
 	(dolist (arg args)
 	  (if (and (listp arg) (eql (cadr arg) '$gnuplot_preamble))
 	      (setq preamble (format nil "~a; ~a"
-				     preamble (caddr arg)))))
+				     preamble (meval (maxima-substitute aval a (caddr arg)))))))
 	(apply #'$plot2d `(,(meval expr) ,@(mapcar #'meval args)
 			   ((mlist simp) $plot_format $gnuplot)
 			   ((mlist simp) $gnuplot_preamble ,preamble)
 			   ((mlist simp) $gnuplot_term $png)
 			   ((mlist simp) $gnuplot_out_file ,filename)))
 	(setq images (cons filename images))))
-    ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))
+    (when images
+      ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide"))))
   "")
 
 (defmspec $with_slider (scene)
@@ -1139,77 +1244,81 @@
 
 (defvar *windows-OS* (string= *autoconf-win32* "true"))
 
-(defun draw-transform (arg trans)
-  (declare (ignore trans))
-  arg)
+(defun get-file-name-opt (scene)
+  (let (opts filename)
+    (loop for opt in scene do
+         (if (and (not (atom opt))
+                  (eq (caar opt) 'mequal)
+                  (eq (cadr opt) '$file_name))
+             (setq filename (caddr opt))
+             (setq opts (cons opt opts))))
+    (values (reverse opts) filename)))
 
-(defun wxanimate-draw (scene)
-  (let* ((scene (cdr scene))
-	 (a (meval (car scene)))
-	 (a-range (meval (cadr scene)))
-	 (args (cddr scene))
-	 (images ()))
-    (when (integerp a-range)
-      (setq a-range (mfuncall '$makelist 'i 'i 1 a-range)))
-    (dolist (aval (reverse (cdr a-range)))
-      (let* ((filename (wxplot-filename nil))
-	     (*windows-OS* t)
-	     (args (cons '($gr2d)
-			 (draw-transform
-			  (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
-				  args)
-			  '$draw2d_transform))))
-	(setq images (cons (format nil "~a.png" filename) images))
-	($apply '$draw
-		(append
-		 `((mlist simp)
-		   ((mequal simp) $terminal $png)
-		   ((mequal simp) $pic_width ,($first $wxplot_size))
-		   ((mequal simp) $pic_height ,($second $wxplot_size))
-		   ((mequal simp) $file_name ,filename))
-		 (list args)))))
-    ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))
-  "")
+(defun get-pic-size-opt ()
+  (cond
+    ((= ($get '$draw '$version) 1)
+     `(((mequal simp) $pic_width ,($first $wxplot_size))
+       ((mequal simp) $pic_height ,($second $wxplot_size))))
+    (t
+     `(((mequal simp) $dimensions ,$wxplot_size)))))
+
+(defun wxanimate-draw (scenes scene-head)
+  (unless ($get '$draw '$version) ($load "draw"))
+  (multiple-value-bind (scene file-name) (get-file-name-opt (cdr scenes))
+    (let* ((a (meval (car scene)))
+           (a-range (meval (cadr scene)))
+           (*windows-OS* t)
+           (args (cddr scene))
+           (images ()))
+      (when (integerp a-range)
+        (setq a-range (cons '(mlist simp) (loop for i from 1 to a-range collect i))))
+      (if file-name
+          ;; If file_name is set, draw the animation into gif using gnuplot
+          (let (imgs)
+            (dolist (aval (reverse (cdr a-range)))
+              (setq imgs (cons
+                          (cons scene-head
+                                (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
+                                        args))
+                          imgs)))
+            ($apply '$draw
+                    (append
+                     `((mlist simp)
+                       ((mequal simp) $terminal $animated_gif)
+                       ((mequal simp) $file_name ,file-name))
+                     (get-pic-size-opt)
+                     imgs))
+            "")
+          ;; If file_name is not set, show the animation in wxMaxima
+          (progn
+            (dolist (aval (reverse (cdr a-range)))
+              (let* ((filename (wxplot-filename nil))
+                     (args (cons scene-head
+                                 (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
+                                         args))))
+                (setq images (cons (format nil "~a.png" filename) images))
+                ($apply '$draw
+                        (append
+                         `((mlist simp)
+                           ((mequal simp) $terminal $png)
+                           ((mequal simp) $file_name ,filename))
+                         (get-pic-size-opt)
+                         (list args)))))
+            (when images
+              ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))))
+      "")))
 
 (defmspec $wxanimate_draw (scene)
-  (wxanimate-draw scene))
+  (wxanimate-draw scene '($gr2d)))
 
 (defmspec $with_slider_draw (scene)
-  (wxanimate-draw scene))
-
-(defun wxanimate-draw3d (scene)
-  (let* ((scene (cdr scene))
-	 (a (meval (car scene)))
-	 (a-range (meval (cadr scene)))
-	 (args (cddr scene))
-	 (images ()))
-    (when (integerp a-range)
-      (setq a-range (mfuncall '$makelist 'i 'i 1 a-range)))
-    (dolist (aval (reverse (cdr a-range)))
-      (let* ((filename (wxplot-filename nil))
-	     (*windows-OS* t)
-	     (args (cons '($gr3d)
-			 (draw-transform
-			  (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
-				  args)
-			  '$draw3d_transform))))
-	(setq images (cons (format nil "~a.png" filename) images))
-	($apply '$draw
-		(append
-		 `((mlist simp)
-		   ((mequal simp) $terminal $png)
-		   ((mequal simp) $pic_width ,($first $wxplot_size))
-		   ((mequal simp) $pic_height ,($second $wxplot_size))
-		   ((mequal simp) $file_name ,filename))
-		 (list args)))))
-    ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))
-  "")
+  (wxanimate-draw scene '($gr2d)))
 
 (defmspec $with_slider_draw3d (scene)
-  (wxanimate-draw3d scene))
+  (wxanimate-draw scene '($gr3d)))
 
 (defmspec $wxanimate_draw3d (scene)
-  (wxanimate-draw3d scene))
+  (wxanimate-draw scene '($gr3d)))
 
 (defun $wxplot2d (&rest args)
   (let ((preamble ($wxplot_preamble))
@@ -1250,37 +1359,42 @@
   "")
 
 
-(dolist (fun '($draw $draw2d $draw3d $set_draw_defaults))
-  (setf (get fun 'autoload) "draw"))
-
 (defun $wxdraw2d (&rest args)
   (apply #'$wxdraw
-	 (list (cons '($gr2d) (draw-transform args '$draw2d_transform)))))
+	 (list (cons '($gr2d) args))))
 
 (defun $wxdraw3d (&rest args)
   (apply #'$wxdraw
-	 (list (cons '($gr3d) (draw-transform args '$draw3d_transform)))))
+	 (list (cons '($gr3d) args))))
 
 (defvar $display_graphics t)
 
 (defun $wxdraw (&rest args)
+  (unless ($get '$draw '$version) ($load "draw"))
   (let* ((filename (wxplot-filename nil))
 	 (*windows-OS* t)
 	 res)
     (setq res ($apply '$draw
-		     (append
-		      `((mlist simp)
-			((mequal simp) $terminal $png)
-			((mequal simp) $pic_width ,($first $wxplot_size))
-			((mequal simp) $pic_height ,($second $wxplot_size))
-			((mequal simp) $file_name ,filename))
-		      args)))
+                      (append
+                       `((mlist simp)
+                         ((mequal simp) $terminal $png)
+                         ((mequal simp) $file_name ,filename))
+                       (cond
+                         ((= ($get '$draw '$version) 1)
+                          `(((mequal simp) $pic_width ,($first $wxplot_size))
+                            ((mequal simp) $pic_height ,($second $wxplot_size))))
+                         (t
+                          `(((mequal simp) $dimensions ,$wxplot_size))))
+                       args)))
     (if $display_graphics
-	($ldisp `((wxxmltag simp) ,(format nil "~a.png" filename) "img"))
+	(progn
+          ($ldisp `((wxxmltag simp) ,(format nil "~a.png" filename) "img"))
+          (setq res ""))
 	(setf res `((wxxmltag simp) ,(format nil "~a.png" filename) "img")))
     res))
 
 (defmspec $wxdraw_list (args)
+  (unless ($get '$draw '$version) ($load "draw"))
   (let (($display_graphics nil))
     ($ldisp (cons '(mlist simp) (mapcar #'meval (cdr args)))))
   '$done)
@@ -1335,15 +1449,27 @@
 (defun $wxxmlput (e s &optional tx lbp rbp)
   (cond (($listp s)
 	 (setq s (margs s)))
-	(t
-	 (setq s (list ($sconcat s)))))
-  (setq s (mapcar #'wxxml-stripdollar s))
+	((atom s)
+	 (setq s (list (wxxml-stripdollar ($sconcat s))))))
   (cond ((or (null lbp) (not (integerp lbp)))
          (setq lbp 180)))
   (cond ((or (null rbp) (not (integerp rbp)))
          (setq rbp 180)))
   (cond ((null tx)
-	 (putprop e (nth 0 s) 'wxxmlword))
+         (if (stringp (nth 0 s))
+             (putprop e (nth 0 s) 'wxxmlword)
+             (let ((fun-name (gensym))
+                   (fun-body
+                    `(append l
+                             (list
+                              (let ((f-x (mfuncall ',s x)))
+                                (if (stringp f-x)
+                                    f-x
+                                    (merror "wxxml: function ~s did not return a string.~%"
+                                            ($sconcat ',(nth 0 s))))))
+                             r)))
+               (setf (symbol-function fun-name) (coerce `(lambda (x l r) ,fun-body) 'function))
+               (setf (get e 'wxxml) fun-name))))
 	((eq tx '$matchfix)
 	 (putprop e 'wxxml-matchfix 'wxxml)
 	 (cond ((< (length s) 2)
@@ -1488,6 +1614,8 @@
 	(m (apply #'max (mapcar '$length (cdr mat))))
 	(n (length (cdr mat)))
 	(mtrx '(special)))
+    (when ($assoc '$transpose opts)
+      (rotatef m n))
     (when (eq row-names '$auto)
       (setq row-names (cons '(mlist simp) (loop for i from 1 to n collect i))))
     (when (eq col-names '$auto)
@@ -1504,6 +1632,8 @@
 				   (lambda (r) ($append r (make-zeros (- m ($length r)))))
 				   (cdr mat))))
     (setq mat ($apply '$matrix mat))
+    (when ($assoc '$transpose opts)
+      (setq mat ($transpose mat)))
     (when row-names
       (setq mat (cons '($matrix simp)
 		      (mapcar #'$append (cdr ($transpose row-names)) (cdr mat))))
@@ -1512,12 +1642,18 @@
       (setq mat (cons '(matrix simp)
 		      (cons col-names (cdr mat))))
       (setq mtrx (cons 'colnames mtrx)))
-    (cons (append '($matrix simp) mtrx) (cdr mat))))
+    ($ldisp (cons (append '($matrix simp) mtrx) (cdr mat)))
+    '$done))
 
 ;; Load the initial functions (from mac-init.mac)
 (let ((*print-circle* nil))
   (format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>"
 	  (mapcar #'$print_function (cdr ($append $functions $macros)))))
 
+(no-warning
+ (defun mredef-check (fnname)
+   (declare (ignore fnname))
+   t))
+
 (when ($file_search "wxmaxima-init")
   ($load "wxmaxima-init"))
