@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -62,6 +62,10 @@ enum {
   popid_animation_start,
   popid_evaluate,
   popid_merge_cells,
+  popid_insert_text,
+  popid_insert_title,
+  popid_insert_section,
+  popid_insert_subsection,
   // popid_complete_00 should be the last id
   popid_complete_00
 };
