@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2007-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -279,7 +279,11 @@ bool SlideShow::ToGif(wxString file)
 
   convert << wxT(" \"") << file << wxT("\"");
 
+#if defined __WXMSW__
+  if (!wxShell(convert))
+#else
   if (wxExecute(convert, wxEXEC_SYNC) != 0)
+#endif
   {
     retval = false;
     wxMessageBox(_("There was and error during GIF export!\n\nMake sure ImageMagick is installed and wxMaxima can find the convert program."),
