@@ -1,5 +1,6 @@
 ///
-///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+///                2011-2011 cw.ahbong <cwahbong@users.sourceforge.net>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -53,7 +54,7 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
   SetStatusWidths(2, widths);
 
 #if defined __WXMSW__
-  wxAcceleratorEntry entries[0];
+  wxAcceleratorEntry entries[1];
   entries[0].Set(wxACCEL_CTRL,  WXK_RETURN, menu_evaluate);
   wxAcceleratorTable accel(1, entries);
   SetAcceleratorTable(accel);
@@ -292,17 +293,17 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2->Append(menu_autocomplete_templates, _("Show Template\tCtrl-Shift-K"),
                              _("Show function template"), wxITEM_NORMAL);
   wxglade_tmp_menu_2->AppendSeparator();
-  wxglade_tmp_menu_2->Append(menu_insert_input, _("Insert Input &Cell\tF5"),
+  wxglade_tmp_menu_2->Append(menu_insert_input, _("Insert Input &Cell"),
                              _("Insert a new input cell"));
-  wxglade_tmp_menu_2->Append(menu_add_comment, _("Insert &Text Cell\tF6"),
+  wxglade_tmp_menu_2->Append(menu_add_comment, _("Insert &Text Cell\tCtrl-1"),
                              _("Insert a new text cell"));
-  wxglade_tmp_menu_2->Append(menu_add_subsection, _("Insert S&ubsection Cell\tF7"),
-                             _("Insert a new subsection cell"));
-  wxglade_tmp_menu_2->Append(menu_add_section, _("Insert &Section Cell\tF8"),
-                             _("Insert a new section cell"));
-  wxglade_tmp_menu_2->Append(menu_add_title, _("Insert T&itle Cell\tF9"),
+  wxglade_tmp_menu_2->Append(menu_add_title, _("Insert T&itle Cell\tCtrl-2"),
                              _("Insert a new title cell"));
-  wxglade_tmp_menu_2->Append(menu_add_pagebreak, _("Insert Page Break\tF10"),
+  wxglade_tmp_menu_2->Append(menu_add_section, _("Insert &Section Cell\tCtrl-3"),
+                             _("Insert a new section cell"));
+  wxglade_tmp_menu_2->Append(menu_add_subsection, _("Insert S&ubsection Cell\tCtrl-4"),
+                             _("Insert a new subsection cell"));
+  wxglade_tmp_menu_2->Append(menu_add_pagebreak, _("Insert Page Break"),
                              _("Insert a page break"));
   wxglade_tmp_menu_2->Append(menu_insert_image, _("Insert Image..."),
                              _("Insert image"), wxITEM_NORMAL);
@@ -312,7 +313,7 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2->Append(menu_history_next, _("Next Command\tAlt-Down"),
                              _("Recall next command from history"), wxITEM_NORMAL);
 
-  frame_1_menubar->Append(wxglade_tmp_menu_2, _("&Cell"));
+  frame_1_menubar->Append(wxglade_tmp_menu_2, _("Ce&ll"));
 
   // Maxima menu
   wxglade_tmp_menu_2 = new wxMenu;
@@ -688,9 +689,14 @@ void wxMaximaFrame::SetupToolBar()
 
   frame_1_toolbar->SetToolBitmapSize(wxSize(22, 22));
 
+#if defined __WXMSW__
+  frame_1_toolbar->AddTool(tb_new, _("New"),
+                           IMAGE("new.png"),
+			               _("New document"));
+#endif
   frame_1_toolbar->AddTool(tb_open, _("Open"),
                            IMAGE("open.png"),
-			                     _("Open document"));
+			               _("Open document"));
   frame_1_toolbar->AddTool(tb_save, _("Save"),
                            IMAGE("save.png"),
                            _("Save document"));
@@ -747,6 +753,11 @@ void wxMaximaFrame::SetupToolBar()
 {
   wxToolBar* frame_1_toolbar = CreateToolBar();
 
+  frame_1_toolbar->AddTool(tb_new, _("New"),
+                           wxArtProvider::GetBitmap(wxT("gtk-new"),
+                                                    wxART_TOOLBAR),
+                           _("New document"));
+
   frame_1_toolbar->AddTool(tb_open, _("Open"),
                            wxArtProvider::GetBitmap(wxT("gtk-open"),
                                                     wxART_TOOLBAR),
