@@ -1,5 +1,5 @@
 ///
-///  Copyright (C) 2004-2009 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///  Copyright (C) 2004-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ///
 ///  This program is free software; you can redistribute it and/or modify
 ///  it under the terms of the GNU General Public License as published by
@@ -182,6 +182,9 @@ enum {
   menu_export_html,
   menu_change_var,
   menu_nouns,
+#if defined (__WXMSW__) || defined (__WXGTK20__) 
+  tb_new,
+#endif
 #if defined (__WXMSW__) || defined (__WXGTK20__) || defined (__WXMAC__)
   tb_open,
   tb_save,
